@@ -27,32 +27,11 @@ class TestInsert(TestCase):
         article.content = u'Some content'
         self.session.add(article)
         self.session.flush()
-        article = self.Article()
-        article.name = u'Some article'
-        article.content = u'Some content'
-        self.session.add(article)
+        article2 = self.Article()
+        article2.name = u'Some article'
+        article2.content = u'Some content'
+        self.session.add(article2)
         self.session.flush()
         self.session.commit()
-
-    def test_relationships(self):
-        article = self.Article()
-        article.name = u'Some article'
-        article.content = u'Some content'
-        article.tags.append(self.Tag(name=u'some tag'))
-        self.session.add(article)
-        self.session.commit()
-        version = article.versions.all()[0]
-        assert version.name == u'Some article'
-        assert version.content == u'Some content'
-        version = article.tags[0].versions.all()[0]
-        assert version.name == u'some tag'
-
-    def test_insert_related_object(self):
-        article = self.Article()
-        article.name = u'Some article'
-        article.content = u'Some content'
-        self.session.add(article)
-        self.session.commit()
-
-        self.session.add(self.Tag(name=u'some tag', article=article))
-        self.session.commit()
+        assert article.versions.count() == 1
+        assert article2.versions.count() == 1
